-- ============================================================
--
--   All Space Object Class
--
-- ============================================================


-- ============================================================
--   Class definition
-- ============================================================
--
clsAnimation = class("clsAnimation")
--
-- ============================================================


-- ============================================================
--   initialize : called at new()
-- ============================================================
--
function clsAnimation:initialize(
	strFileName, numNX, numNY, numScale,
	numX, numY, numHeading,
	numSpeedX, numSpeedY, numRotationSpeed
)
	-- DEBUG
	-- print ( "Raw arguments       : ", strFileName, numNX, numNY, numScale, numX, numY, numHeading, numSpeedX, numSpeedY, numRotationSpeed )

	-- Check parameters and enforce default values
	if strFileName == "" or strFileName == nil then
		strFileName = "explosion"
	end
	if numNX == nil then
		numNX = 6
	end
	if numNY == nil then
		numNY = 6
	end
	if numScale == nil then
		numScale = 1
	end
	if numX == nil then
		numX = love.graphics.getWidth()/2
	end
	if numY == nil then
		numY = love.graphics.getHeight()/2
	end
	if numHeading == nil then
		numHeading = 0
	end
	if numSpeedX == nil then
		numSpeedX = 0
	end
	if numSpeedY == nil then
		numSpeedY = 0
	end
	if numRotationSpeed == nil then
		numRotationSpeed = 0
	end

	-- DEBUG
	-- print ( "Processed arguments : ", strFileName, numNX, numNY, numX, numY, numHeading, numSpeedX, numSpeedY, numRotationSpeed )

	-- State properties
	self.position       = {x = numX     , y = numY     , heading  = numHeading      }
	self.speed          = {x = numSpeedX, y = numSpeedY, rotation = numRotationSpeed}

	-- Sprite property
	self.sprite = {
		image  = love.graphics.newImage(strFileName),
		number = {x = numNX, y = numNY},
		scale = numScale,
		frame  = {}
	}
	numImageWidth, numImageHeight = self.sprite.image:getDimensions()
	self.sprite.width  = numImageWidth/self.sprite.number.x
	self.sprite.height = numImageHeight/self.sprite.number.y
	self.sprite.total  = self.sprite.number.x * self.sprite.number.y

	-- Generate the quads to display the images in the sprite
	-- frame[i] corresponds to [i, i+10[
	for y=0, self.sprite.number.y-1, 1 do
		for x=0, self.sprite.number.x-1, 1 do
			i = x+y*self.sprite.number.x
			self.sprite.frame[i] = love.graphics.newQuad(
				x*self.sprite.width,
				y*self.sprite.height,
				self.sprite.width,
				self.sprite.height,
				self.sprite.image:getDimensions())
		end
	end

	-- Init to 1st frame
	self.currentFrame = 0
end
--
-- ============================================================


-- ============================================================
--   update : called by the game's global love.update()
-- ============================================================
--
function clsAnimation:update(dt)
	-- Update position in pixel from speed
	self.position.x = self.position.x + dt*self.speed.x
	self.position.y = self.position.y + dt*self.speed.y

	-- Update heading in degrees from rotation speed
	self.position.heading = (self.position.heading + dt*self.speed.rotation) % math.rad(360)
end
--
-- ============================================================


-- ============================================================
--   draw : called by the game's global love.draw()
-- ============================================================
--
function clsAnimation:draw()
	if self.currentFrame~=-1 then
		-- Get corresponding quad for selecting sprite
		local activeFrame = self.sprite.frame[self.currentFrame]

		-- Draw the sprite
		love.graphics.draw(
			self.sprite.image,
			activeFrame,
			self.position.x,
			self.position.y,
			0,
			self.sprite.scale,
			self.sprite.scale,
			self.sprite.width/2,
			self.sprite.height/2
		)

		-- Increment the frame
		self.currentFrame = self.currentFrame+1
		if self.currentFrame>self.sprite.total-1 then
			self.currentFrame=-1
		end
	end
end
--
-- ============================================================

