-- ============================================================
--
--   The game's "Menu" state
--
-- ============================================================


-- ============================================================
-- Define the state and its variables
--   Here will be the actual gameflow
-- ============================================================
--
-- Create the state
local stateMenu = clsGame:addState("Menu")

-- Current ship displayed
local objShip = nil

-- Set the layout for displaying the main menu and the prev/next buttons
local layoutLeft  = Layout( require("src/classes/clsGame/stateMenu/layoutLeft") )
local layoutRight = Layout( require("src/classes/clsGame/stateMenu/layoutRight") )
local layoutMenu  = Layout( require("src/classes/clsGame/stateMenu/layoutMenu") )

-- Give layouts style
layoutLeft:setStyle( require("src/gui/styleDefault") )
layoutRight:setStyle( require("src/gui/styleDefault") )
layoutMenu:setStyle( require("src/gui/styleDefault") )

-- Set an action for each Menu button
layoutMenu.btnStart:onPress(
	function()
		objGame:gotoState("Play")
	end
)
layoutMenu.btnOptions:onPress(
	function()
		objGame:gotoState("Options")
	end
)
layoutMenu.btnCredits:onPress(
	function()
		objGame:gotoState("Credits")
	end
)
layoutMenu.btnExit:onPress(
	function()
		print ( "" )
		love.event.push("quit")
	end
)
-- Set an action for Prev & Next buttons
layoutLeft.btnLeft:onPress(
	function()
		currentShip = currentShip-1
		if (currentShip==0) then
			currentShip = #tabShipData
		end
		local strShipName = tabShipData[currentShip].name
		local strFileName = tabShipData[currentShip].fileName
		local numX, numY  = tabShipData[currentShip].nX, tabShipData[currentShip].nY
		objShip = clsShip:new(strShipName,strFileName, numX, numY)
	end
)
layoutRight.btnRight:onPress(
	function()
		currentShip = currentShip+1
		if (currentShip==#tabShipData+1) then
			currentShip = 1
		end
		local strShipName = tabShipData[currentShip].name
		local strFileName = tabShipData[currentShip].fileName
		local numX, numY  = tabShipData[currentShip].nX, tabShipData[currentShip].nY
		objShip = clsShip:new(strShipName,strFileName, numX, numY)
	end
)
--
-- ============================================================


-- ============================================================
-- Called when entering the state
-- ============================================================
--
function stateMenu:enterState()
	-- print ( "enterState : before resizing" )
	for k,v in pairs(layoutMenu.root) do
		-- print ( "\t", k,v )
	end

	-- Init ship
	currentShip = math.random(1,#tabShipData)
	local strShipName = tabShipData[currentShip].name
	local strFileName = tabShipData[currentShip].fileName
	local numX, numY  = tabShipData[currentShip].nX, tabShipData[currentShip].nY
	objShip = clsShip:new(strShipName,strFileName, numX, numY)

	-- Resize main menu widgets if resolution changed
	local numHeight = 100
	local numButtonHeight = 50
	local numButtonSpace = 10
	local numButtonWidth = (love.graphics.getWidth()/2-5*numButtonSpace)/4
	local numLayoutY = love.graphics.getHeight()-2*numHeight
	layoutMenu.root.top = numLayoutY
	layoutMenu.root.height = numButtonHeight+2*numButtonSpace
	layoutMenu.root.width = 4*numButtonWidth+1*numButtonSpace
	layoutMenu.btnStart.width   = numButtonWidth
	layoutMenu.btnOptions.width = numButtonWidth
	layoutMenu.btnCredits.width = numButtonWidth
	layoutMenu.btnExit.width    = numButtonWidth

	-- Resize left menu widgets if resolution changed
	local numButtonWidth  =  50
	local numButtonHeight = 150
	local numLayoutX = 10
	local numLayoutY = (love.graphics.getHeight() - numButtonHeight)/2
	layoutLeft.root.top = numLayoutY

	-- Resize right menu widgets if resolution changed
	local numButtonWidth  =  50
	local numButtonHeight = 150
	local numLayoutX = love.graphics.getWidth() - 10 - numButtonWidth
	local numLayoutY = (love.graphics.getHeight() - numButtonHeight)/2
	layoutRight.root.left = numLayoutX
	layoutRight.root.top  = numLayoutY

	-- print ( "enterState : after resizing" )
	for k,v in pairs(layoutMenu.root) do
		-- print ( "\t", k,v )
	end

	-- Finally show the buttons panel
	layoutLeft:show()
	layoutRight:show()
	layoutMenu:show()
end
--
-- ============================================================


-- ============================================================
-- Called when exiting the state to enter another state
-- ============================================================
--
function stateMenu:exitState()
	-- print("stateMenu:exitState()")
	layoutMenu:hide()
	layoutLeft:hide()
	layoutRight:hide()
	objShip = nil
end
--
-- ============================================================


-- ============================================================
-- update() callback
--   called instead of the regular clsGame:update()
--   when the game is in the Menu state
-- ============================================================
--
function stateMenu:update(dt)
	objShip:update(dt,1,0)
end
--
-- ============================================================


-- ============================================================
-- draw() callback
--   called instead of the regular clsGame:draw()
--   when the game is in the Menu state
-- ============================================================
--
function stateMenu:draw()
	objShip:draw()
end
--
-- ============================================================


-- ============================================================
-- keypressed and keyreleased callback
--   called instead of the regular clsGame:keyreleased()
--   when the game is in the Menu state
-- ============================================================
--
function stateMenu:keypressed(key)   -- we do not need the unicode, so we can leave it out
	-- DEBUG
	-- print ( "State : Menu" )
	-- print("Key : \"" .. tostring(key) .. "\" has been pressed")
end
function stateMenu:keyreleased(key)
	-- DEBUG
	-- print ( "State : Menu" )
	-- print("Key : \"" .. tostring(key) .. "\" has been released")
end
--
-- ============================================================
