-- ============================================================
--
--   The game's "Menu" state
--
-- ============================================================


-- ============================================================
-- Define the state and its variables
--   Here will be the actual gameflow
-- ============================================================
--
-- Create the state
local stateOptions = clsGame:addState("Options")

-- Set the layout and style for displaying the menu
local layoutOptions = Layout( require("src/classes/clsGame/stateOptions/layoutOptions") )
layoutOptions:setStyle( require("src/gui/styleDefault") )

-- Set an action for each Menu button
layoutOptions.btnCancel:onPress(
	function()
		objGame:gotoState("Menu")
	end
)
layoutOptions.btnApply:onPress(
	function()
		if layoutOptions.chkFullscreen.value then
			-- Just enter fullscreen mode, let LÖVE find the best resolution
			love.window.setFullscreen( true )
		else
			-- For now, use hard-coded globals, should be derived from love.conf values
			local tabLoveConf = {}
			tabLoveConf.window = {}
			tabLoveConf.modules = {}
			love.conf(tabLoveConf)
			-- for k,v in pairs(tabLoveConf) do
			-- 	print ( k,v )
			-- end
			love.window.setMode(tabLoveConf.window.width, tabLoveConf.window.height, {fullscreen=false})
			-- love.window.setMode(numDefaultWindowWidth, numDefaultWindowHeight, {fullscreen=false})
		end

		-- Display menu
		objGame:gotoState("Menu")
	end
)
--
-- ============================================================


-- ============================================================
-- Called when entering the state
-- ============================================================
--
function stateOptions:enterState()
	layoutOptions.chkFullscreen.value = love.window.getFullscreen()
	-- Show panel
	layoutOptions:show()
end
--
-- ============================================================


-- ============================================================
-- Called when exiting the state to enter another state
-- ============================================================
--
function stateOptions:exitState()
	layoutOptions:hide()
end
--
-- ============================================================


-- ============================================================
-- update() callback
--   called instead of the regular clsGame:update()
--   when the game is in the Menu state
-- ============================================================
--
function stateOptions:update(dt)
end
--
-- ============================================================


-- ============================================================
-- draw() callback
--   called instead of the regular clsGame:draw()
--   when the game is in the Menu state
-- ============================================================
--
function stateOptions:draw()
end
--
-- ============================================================


-- ============================================================
-- keypressed and keyreleased callback
--   called instead of the regular clsGame:keyreleased()
--   when the game is in the Menu state
-- ============================================================
--
function stateOptions:keypressed(key)   -- we do not need the unicode, so we can leave it out
	-- DEBUG
	-- print ( "State : Options" )
	-- print ( type(key) )
	if type(key)=="table" then
		-- print("A keys sequence has been pressed :")
		for i,v in ipairs(key) do
			-- print( "\t Key : " .. v)
		end
	else
		-- print("Key : \"" .. tostring(key) .. "\" has been pressed")
	end
end
function stateOptions:keyreleased(key)
	-- DEBUG
	-- print ( "State : Options" )
	-- print("Key : \"" .. tostring(key) .. "\" has been released")
end
--
-- ============================================================
