-- ============================================================
--
--   Ship Object Class
--
-- ============================================================


-- ============================================================
--   Class definition
-- ============================================================
--
clsAsteroid = class("clsAsteroid", clsSpaceObject)
--
-- ============================================================


-- ============================================================
--   initialize : called at new()
-- ============================================================
--
function clsAsteroid:initialize(
	strImageName, numSize,
	numX, numY, numHeading,
	numSpeedX, numSpeedY, numRotationSpeed
)
	-- Check parameters and enforce default values
	if strImageName == "" or strImageName == nil then
		strImageName = "asteroid-D00"
	end
	if numSize == nil then
		numSize = 2
	end
	if numX == nil then
		numX = 0
	end
	if numY == nil then
		numY = 0
	end
	if numHeading == nil then
		numHeading = 0
	end
	if numSpeedX == nil then
		numSpeedX = 0
	end
	if numSpeedY == nil then
		numSpeedY = 0
	end
	if numRotationSpeed == nil then
		numRotationSpeed = 90
	end

	-- DEBUG
	-- print ( strImageName, numSize, numX, numY, numHeading, numSpeedX, numSpeedY, numRotationSpeed )
	-- print ( math.deg(numRotationSpeed) )

	-- Call parent class
	local strAstImageFile = strAstImagesDir .. "/" .. strImageName .. ".png"
	clsSpaceObject.initialize(self, strAstImageFile, 1, 1, numSize/2, numX, numY, numHeading, numSpeedX, numSpeedY, numRotationSpeed)

	-- Capacity properties : rotation is constant
	self.size = numSize
	self.capabilities = {
		rotation     =  numRotationSpeed -- Deg/sec
	}

	-- Flags
	self.leftScreen = false -- Previously visible asteroid left the screen
	self.isDanger   = false -- Asteroid is dangerous for the player, but not yet colliding
end
--
-- ============================================================


-- ============================================================
--   update : called by the game's global love.update()
-- ============================================================
--
function clsAsteroid:update(dt, cmdRotation, cmdAcceleration)
	-- If left screen, do nothing
	if self.leftScreen then
		return
	end

	-- First call parent class
	clsSpaceObject.update(self, dt)

	-- Check and flag if offscreen
	-- self.leftScreen = (
	-- 	   self.position.x+self.sprite.width  < 0
	-- 	or self.position.y+self.sprite.height < 0
	-- 	or self.position.x-self.sprite.width  > love.graphics.getWidth()
	-- 	or self.position.y-self.sprite.height > love.graphics.getHeight()
	-- )
end
--
-- ============================================================
