-- ============================================================
--
--   Ship Object Class
--
-- ============================================================


-- ============================================================
--   Class definition
-- ============================================================
--
clsShip = class("clsShip", clsSpaceObject)
--
-- ============================================================


-- ============================================================
--   initialize : called at new()
-- ============================================================
--
function clsShip:initialize(
	strClassName, strFileName, numNX, numNY,	-- Ship definition
	numX, numY, numHeading,						-- Initial position (px, px, rad)
	numSpeedX, numSpeedY, numRotation,			-- Initial speed (px/s, px/s, rad/s)
	numAccelerationMax,							-- Maximal acceleration (px/s/s)
	numRotationSpeedMax							-- Maximal rotation (rad/s)
)
	-- Check parameters and enforce default values
	if strClassName == "" or strClassName == nil then
		strFileName = "Alaith"
	end
	if strFileName == "" or strFileName == nil then
		strFileName = strShipImagesDir .. "/alaith/alaith"
	end
	if numNX == nil then
		numNX = 6
	end
	if numNY == nil then
		numNY = 6
	end
	if numX == nil then
		numX = love.graphics.getWidth()/2
	end
	if numY == nil then
		numY = love.graphics.getHeight()/2
	end
	if numHeading == nil then
		numHeading = 0
	end
	if numSpeedX == nil then
		numSpeedX = 0
	end
	if numSpeedY == nil then
		numSpeedY = 0
	end
	if numRotation == nil then
		numRotation = 0
	end
	if numAccelerationMax == nil then
		numAccelerationMax = 50
	end
	if numRotationSpeedMax == nil then
		numRotationSpeedMax = math.rad(90)
	end

	-- Call parent class
	clsSpaceObject.initialize(self, strFileName, numNX, numNY, 1, numX, numY, numHeading, numSpeedX, numSpeedY, numRotation)

	-- Unset New flag
	self.isNew = 0

	-- Capacity properties
	self.capabilities = {
		acceleration  =  numAccelerationMax, -- Pixel/sec/sec
		rotationSpeed =  numRotationSpeedMax -- Deg/sec
	}
end
--
-- ============================================================


-- ============================================================
--   update : called by the game's global love.update()
-- ============================================================
--
function clsShip:update(dt, cmdRotation, cmdAcceleration)
	-- Update rotation speed in deg/sec
	self.speed.rotation = cmdRotation*self.capabilities.rotationSpeed

	-- Convert acceleration command to actual acceleration towards the ship's heading
	self.acceleration.x = cmdAcceleration*self.capabilities.acceleration*math.cos(self.position.heading)
	self.acceleration.y = cmdAcceleration*self.capabilities.acceleration*math.sin(self.position.heading)

	-- DEBUG
	-- if (cmdRotation~=0 or cmdAcceleration~=0) then
	-- 	print ( string.format ( "Commands : (rotation : %i ; acceleration : %i)", cmdRotation, cmdAcceleration ) )
	-- 	print ( string.format ( "Results  : (acc.x : %f ; acc.y : %f ; rotSpeed : %f", self.acceleration.x, self.acceleration.y, self.speed.rotation ) )
	-- end

	-- Finally call parent class
	clsSpaceObject.update(self, dt)
end
--
-- ============================================================
