-- ============================================================
--
--   functions used everywhere
--
-- ============================================================


-- ============================================================
--   Interprets keyboard commands 
-- ============================================================
--
function interpretCommands()
	-- Transform keyboard arrows into movement commands
	local cmdRotation = 0
	local cmdAcceleration    = 0
	if love.keyboard.isDown("right") then
		cmdRotation = cmdRotation + 1
	end
	if love.keyboard.isDown("left") then
		cmdRotation = cmdRotation - 1
	end
	if love.keyboard.isDown("up") then
		cmdAcceleration = cmdAcceleration + 1
	end
	if love.keyboard.isDown("down") then
		cmdAcceleration = cmdAcceleration - 1
	end

	-- Return found commands
	return cmdRotation, cmdAcceleration
end
--
-- ============================================================


-- ============================================================
--   Returns a single asteroid
-- ============================================================
--
function generateAsteroid(strImageName, insideScreen)
	-- Declare locals
	local numSize, numX, numY, numHeading, numSpeedX, numSpeedY, numRotationSpeed
	local numRadiusMin, numRadiusMax
	local numRadius, numAngle

	if insideScreen then
		-- Generate position by angle and distance,
		-- in the screen but as far as possible from the ship's starting position
		numRadiusMax = math.min( love.graphics.getWidth(), love.graphics.getHeight() ) / 2 / 1.25
		numRadiusMin = numRadiusMax/2

		-- Generate position
		numRadius  = math.random(numRadiusMin, numRadiusMax)
		numAngle = math.rad(math.random()*360)
		numX     = love.graphics.getWidth() /2 + numRadius * math.cos(numAngle)
		numY     = love.graphics.getHeight()/2 + numRadius * math.sin(numAngle)

		-- Speed can be in any direction
		numSpeedX  = 100-math.random()*200
		numSpeedY  = 100-math.random()*200
	else
		-- Asteroid is outside the screen, but will pass through it : used to generate new asteroids during the game
		numRadiusMin = math.min( love.graphics.getWidth(), love.graphics.getHeight() ) / math.sqrt(2)
		numRadiusMax = numRadiusMin*1.5

		-- Generate position
		numRadius  = math.random(numRadiusMin, numRadiusMax)
		numAngle = math.rad(math.random()*360)
		numX     = love.graphics.getWidth() /2 + numRadius * math.cos(numAngle)
		numY     = love.graphics.getHeight()/2 + numRadius * math.sin(numAngle)

		-- NOT YET IMPLEMENTED - Speed must be directed towards the screen
		local deltaX = numX-(love.graphics.getWidth() /2)
		local deltaY = numY-(love.graphics.getHeight()/2)
		numSpeedX  = math.random()*100*(-deltaX/math.abs(deltaX))
		numSpeedY  = math.random()*100*(-deltaY/math.abs(deltaY))
	end

	-- Generate initial heading and rotation speed
	numHeading = math.rad(math.random()*360)
	numRotationSpeed = math.rad(90-math.random()*180)

	-- Generate size
	numSize = math.random(1, 3)

	-- DEBUG
	-- print ( strImageName, numX, numY, numHeading, numSpeedX, numSpeedY, numRotationSpeed )

	-- Actually generate the asteroid, without the isNew flag
	newAsteroid = clsAsteroid:new(strImageName, numSize, numX, numY, numHeading, numSpeedX, numSpeedY, numRotationSpeed)
	newAsteroid.isNew = 0
	return newAsteroid
end
--
-- ============================================================


-- ============================================================
--   Destroy a single asteroid, given by its index
-- ============================================================
--
function destroyAsteroid(tabAsteroids, numIndexInTable)
	-- DEBUG
	-- print ( string.format( "\tDestroying asteroid #%i", numIndexInTable ) )

	-- Check argument
	if numIndexInTable<1 then
		print("\t>>> ERROR while destroying asteroid : numIndexInTable ( " .. tostring(numIndexInTable) .. ")<1")
		return
	end
	if numIndexInTable>#tabAsteroids then
		print("\t>>> ERROR while destroying asteroid : numIndexInTable ( " .. tostring(numIndexInTable) .. ")>#tabAsteroids (" .. tostring(#tabAsteroids) .. ")")
		return
	end

	-- Actually destroy the asteroid
	table.remove (tabAsteroids, numIndexInTable)
end
--
-- ============================================================


-- ============================================================
--   Create new asteroids from 2 colliding asteroids
--       Not completed yet
-- ============================================================
--
function createAsteroidsFromCollision(tabAsteroids, tabAnimations, i, j, strImageName)
	-- DEBUG
	-- print (
	-- 	string.format( "Collision between Asteroids #%i (size %i, weight %i) and #%i (size %i, weight %i)",
	-- 	i, tabAsteroids[i].size, tabAsteroids[i].size^3, j, tabAsteroids[j].size, tabAsteroids[j].size^3 )
	-- )

	-- All generated asteroids will depart from the collision point
	-- Here, take the middle point between original asteroids
	-- Also give them the same base speed as the originals
	local numBaseX = (tabAsteroids[i].position.x + tabAsteroids[j].position.x)/2
	local numBaseY = (tabAsteroids[i].position.y + tabAsteroids[j].position.y)/2
	local numBaseSpeedX = (tabAsteroids[i].speed.x + tabAsteroids[j].speed.x)/2
	local numBaseSpeedY = (tabAsteroids[i].speed.y + tabAsteroids[j].speed.y)/2

	-- First create an animation
	tabAnimations[#tabAnimations+1] = clsAnimation:new(strAstEffectsDir.."/expl2.png", 6, 5, 1, numBaseX, numBaseY, 0, numBaseSpeedX, numBaseSpeedY, 0)

		-- Different cases from sum of weights
	local numTotalWeight = tabAsteroids[i].size^3 + tabAsteroids[j].size^3
	local numRemainingWeight = numTotalWeight

	-- Loop while we can generate something and there are not already too many asteroids in the game
	while numRemainingWeight>1.5 and #tabAsteroids<50 do
		-- Determine the size of the asteroid from what can be generated
		-- given some mass loss in dust
		local numOldRemainingWeight = numRemainingWeight
		local numSize = 0
		if     numRemainingWeight>3^3*1.5 then
			numSize = math.random(2,3)
		elseif numRemainingWeight>2^3*1.5 then
			numSize = 2
		else
			numSize = 1
		end
		numRemainingWeight = numRemainingWeight - numSize^3*1.5

		-- DEBUG
		-- print ( string.format( "\tNew asteroid size : %i, weight %i", numSize, numSize^3 ) )
		-- print ( string.format( "\t\tMass loss : %.2f - %.2f = %.2f", numOldRemainingWeight, numSize^3*1.5, numRemainingWeight ) )

		-- Generate the new asteroid's position not too near its origin point
		local numRadius = numSize*40
		local numAngle  = math.rad(math.random(1,360))
		local numX      = numBaseX + numRadius * math.cos(numAngle)
		local numY      = numBaseY + numRadius * math.sin(numAngle)

		-- Generate speed moving away from collision position
		local numSpeed = math.random(25,50)
		local numSpeedX = numBaseSpeedX + numSpeed * math.cos(numAngle)
		local numSpeedY = numBaseSpeedY + numSpeed * math.sin(numAngle)

		-- Generate initial heading and rotation speed
		local numHeading = math.rad(math.random()*360)
		local numRotationSpeed = math.rad(90-math.random()*180)

		-- Actually generate the asteroid
		tabAsteroids[#tabAsteroids+1] = clsAsteroid:new(strImageName, numSize, numX, numY, numHeading, numSpeedX, numSpeedY, numRotationSpeed)
	end
end
--
-- ============================================================


-- ============================================================
--   Destroy a single animation, given by its index
-- ============================================================
--
function destroyAnimation(tabAnimations, numIndexInTable)
	-- DEBUG
	-- print ( string.format( "\tDestroying animation #%i", numIndexInTable ) )

	-- Check argument
	if numIndexInTable<1 then
		print("\t>>> ERROR while destroying animation : numIndexInTable ( " .. tostring(numIndexInTable) .. ")<1")
		return
	end
	if numIndexInTable>#tabAnimations then
		print("\t>>> ERROR while destroying animation : numIndexInTable ( " .. tostring(numIndexInTable) .. ")>#tabAnimations (" .. tostring(#tabnimations) .. ")")
		return
	end

	-- Actually destroy the asteroid
	table.remove (tabAnimations, numIndexInTable)
end
--
-- ============================================================


