-- ============================================================
--
--   Define global variables
--
-- ============================================================


-- ============================================================
--   Random generator
-- ============================================================
--
math.randomseed(os.time())
--
-- ============================================================


-- ============================================================
--   Paths to date files
-- ============================================================
--
strShipDataDir    = "dat/ships"
strShipImagesDir  = "dat/gfx/ship"
strAstImagesDir   = "dat/gfx/planet/space"
strAstEffectsDir  = "dat/gfx/spfx"
--
-- ============================================================


-- ============================================================
--   Timer and scoring
-- ============================================================
--
elapsedTime = 0
spawnTimer  = 0
gameScore   = 0
--
-- ============================================================


-- ============================================================
-- Ships definition
-- ============================================================
--
-- Init available ships table
tabShipData = {}

-- Get ship definition files from data folder
local tabShipFilesList = love.filesystem.getDirectoryItems( strShipDataDir )
for k, file in ipairs(tabShipFilesList) do
	-- print("Loading ship definition : " .. file) --outputs something like "1. main.lua"
	if string.sub(file,-4)==".xml" then
		--Instantiates the XML parser
		local strXML = love.filesystem.read( strShipDataDir .. "/" .. file )
		-- print ( strXML )
		local doc = SLAXML:dom(strXML)

		-- Get the ship's name
		local strShipName = doc.root.attr[1].value

		-- Get sprite dimensions : if 1x1, do not load
		local numNX = tonumber(doc.root.el[2].attr[1].value)
		local numNY = tonumber(doc.root.el[2].attr[2].value)
		if numNX==1 or numNY==1 then
			print ( "\t>>> ERROR on Ship \"" .. strShipName .. "\" : 1x1 sprite" )
			print ( "\t>>> SHIP LOADING ABORTED" )
		else
			-- Load ship
			local strBaseName = doc.root.el[1].kids[1].value
			local strGFXname  = doc.root.el[2].kids[1].value
			local strDirName  = ""
			if (strShipName == strBaseName) then
				strDirName  = string.lower(strGFXname):gsub("[' ]", "")
			else
				strDirName  = string.lower(strBaseName):gsub("[' ]", "")
			end
			local strFileName = strShipImagesDir .. "/" .. strDirName .. "/" .. strGFXname .. ".png"

			-- Check if image fome exists
			if love.filesystem.isFile(strFileName) then
				tabShipData[#tabShipData+1] = {
					name     = doc.root.attr[1].value,
					fileName = strFileName,
					nX = numNX,
					nY = numNY
				}
				-- print ( "\tSuccessfully loaded ship \"" .. strShipName .. "\"" )
				-- for k,v in pairs(tabShipData[#tabShipData]) do
				-- 	print ( "\t", k,v )
				-- end
			else
				print ( "\t>>> ERROR  on Ship \"" .. strShipName .. "\" : image file \"" .. strFileName .. "\" does not exist" )
				print ( "\t>>> SHIP LOADING ABORTED" )
			end
		end
	end
end

-- print ( "Successfully loaded " .. #tabShipData .. " ships" )

-- Make current the 1st ship in the list
currentShip = math.random(1,#tabShipData)
--
-- ============================================================
